"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CoreComponent = void 0;
const tslib_1 = require("tslib");
const core_1 = require("@loopback/core");
const rest_1 = require("@loopback/rest");
const i18n_1 = require("i18n");
const keys_1 = require("./keys");
const components_1 = require("./components");
const loopback4_helmet_1 = require("loopback4-helmet");
const loopback4_ratelimiter_1 = require("loopback4-ratelimiter");
let CoreComponent = class CoreComponent {
    constructor(application, coreConfig) {
        var _a;
        this.application = application;
        this.coreConfig = coreConfig;
        this.localeObj = {};
        this.providers = {};
        this.bindings = [];
        // Mount logger component
        this.application.component(components_1.LoggerExtensionComponent);
        this.application.component(loopback4_helmet_1.Loopback4HelmetComponent);
        this.application.component(loopback4_ratelimiter_1.RateLimiterComponent);
        // Configure locale provider
        if ((_a = this.coreConfig) === null || _a === void 0 ? void 0 : _a.configObject) {
            i18n_1.configure({ ...this.coreConfig.configObject, register: this.localeObj });
        }
        else {
            i18n_1.configure({
                locales: [
                    "en" /* en */,
                    "es" /* es */,
                    "pt-br" /* ptBr */,
                    "pt-pt" /* ptPt */,
                    "es-co" /* esCo */,
                ],
                fallbacks: {
                    ["es" /* es */]: 'en',
                    ["es-co" /* esCo */]: 'en',
                    ["pt-br" /* ptBr */]: 'en',
                    ["pt-pt" /* ptPt */]: 'en',
                },
                register: this.localeObj,
                directoryPermissions: '777',
                directory: `${__dirname}/../locales`,
                // sonarignore:start
                /* eslint-disable @typescript-eslint/no-explicit-any */
                objectNotation: '->',
            });
        }
        this.bindings.push(core_1.Binding.bind(keys_1.SFCoreBindings.i18n).to(this.localeObj));
    }
};
CoreComponent = tslib_1.__decorate([
    tslib_1.__param(0, core_1.inject(core_1.CoreBindings.APPLICATION_INSTANCE)),
    tslib_1.__param(1, core_1.inject(keys_1.SFCoreBindings.config, { optional: true })),
    tslib_1.__metadata("design:paramtypes", [rest_1.RestApplication, Object])
], CoreComponent);
exports.CoreComponent = CoreComponent;
//# sourceMappingURL=component.js.map