"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DefaultTransactionalUserModifyRepository = void 0;
const repository_1 = require("@loopback/repository");
const rest_1 = require("@loopback/rest");
class DefaultTransactionalUserModifyRepository extends repository_1.DefaultTransactionalRepository {
    constructor(entityClass, dataSource, getCurrentUser) {
        super(entityClass, dataSource);
        this.getCurrentUser = getCurrentUser;
    }
    find(filter, options) {
        if ((filter === null || filter === void 0 ? void 0 : filter.where) &&
            (filter === null || filter === void 0 ? void 0 : filter.where).and &&
            (filter === null || filter === void 0 ? void 0 : filter.where).and.length > 0) {
            (filter === null || filter === void 0 ? void 0 : filter.where).and.push({
                deleted: false,
            });
        }
        else if ((filter === null || filter === void 0 ? void 0 : filter.where) &&
            (filter === null || filter === void 0 ? void 0 : filter.where).or &&
            (filter === null || filter === void 0 ? void 0 : filter.where).or.length > 0) {
            (filter === null || filter === void 0 ? void 0 : filter.where).and = [];
            (filter === null || filter === void 0 ? void 0 : filter.where).and.push({
                deleted: false,
            }, {
                or: (filter === null || filter === void 0 ? void 0 : filter.where).or,
            });
        }
        else {
            // Do nothing
        }
        return super.find(filter, options);
    }
    findOne(filter, options) {
        if ((filter === null || filter === void 0 ? void 0 : filter.where) &&
            (filter === null || filter === void 0 ? void 0 : filter.where).and &&
            (filter === null || filter === void 0 ? void 0 : filter.where).and.length > 0) {
            (filter === null || filter === void 0 ? void 0 : filter.where).and.push({
                deleted: false,
            });
        }
        else if ((filter === null || filter === void 0 ? void 0 : filter.where) &&
            (filter === null || filter === void 0 ? void 0 : filter.where).or &&
            (filter === null || filter === void 0 ? void 0 : filter.where).or.length > 0) {
            (filter === null || filter === void 0 ? void 0 : filter.where).and = [];
            (filter === null || filter === void 0 ? void 0 : filter.where).and.push({
                deleted: false,
            }, {
                or: (filter === null || filter === void 0 ? void 0 : filter.where).or,
            });
        }
        else {
            // Do nothing
        }
        return super.findOne(filter, options);
    }
    findById(id, filter, options) {
        if ((filter === null || filter === void 0 ? void 0 : filter.where) &&
            (filter === null || filter === void 0 ? void 0 : filter.where).and &&
            (filter === null || filter === void 0 ? void 0 : filter.where).and.length > 0) {
            (filter === null || filter === void 0 ? void 0 : filter.where).and.push({
                deleted: false,
            });
        }
        else if ((filter === null || filter === void 0 ? void 0 : filter.where) &&
            (filter === null || filter === void 0 ? void 0 : filter.where).or &&
            (filter === null || filter === void 0 ? void 0 : filter.where).or.length > 0) {
            (filter === null || filter === void 0 ? void 0 : filter.where).and = [];
            (filter === null || filter === void 0 ? void 0 : filter.where).and.push({
                deleted: false,
            }, {
                or: (filter === null || filter === void 0 ? void 0 : filter.where).or,
            });
        }
        else {
            // Do nothing
        }
        return super.findById(id, filter, options);
    }
    async create(entity, options) {
        let currentUser = await this.getCurrentUser();
        currentUser = currentUser !== null && currentUser !== void 0 ? currentUser : options === null || options === void 0 ? void 0 : options.currentUser;
        if (!currentUser) {
            throw new rest_1.HttpErrors.Forbidden("Invalid Credentials" /* InvalidCredentials */);
        }
        entity.createdBy = currentUser.id;
        entity.modifiedBy = currentUser.id;
        return super.create(entity, options);
    }
    async createAll(entities, options) {
        let currentUser = await this.getCurrentUser();
        currentUser = currentUser !== null && currentUser !== void 0 ? currentUser : options === null || options === void 0 ? void 0 : options.currentUser;
        if (!currentUser) {
            throw new rest_1.HttpErrors.Forbidden("Invalid Credentials" /* InvalidCredentials */);
        }
        entities.forEach(entity => {
            entity.createdBy = currentUser ? currentUser.id : '';
            entity.modifiedBy = currentUser ? currentUser.id : '';
        });
        return super.createAll(entities, options);
    }
    async save(entity, options) {
        const currentUser = await this.getCurrentUser();
        if (!currentUser) {
            throw new rest_1.HttpErrors.Forbidden("Invalid Credentials" /* InvalidCredentials */);
        }
        entity.modifiedBy = currentUser.id;
        return super.save(entity, options);
    }
    async update(entity, options) {
        const currentUser = await this.getCurrentUser();
        if (!currentUser) {
            throw new rest_1.HttpErrors.Forbidden("Invalid Credentials" /* InvalidCredentials */);
        }
        entity.modifiedBy = currentUser.id;
        return super.update(entity, options);
    }
    async updateAll(data, where, options) {
        let currentUser = await this.getCurrentUser();
        currentUser = currentUser !== null && currentUser !== void 0 ? currentUser : options === null || options === void 0 ? void 0 : options.currentUser;
        if (!currentUser) {
            throw new rest_1.HttpErrors.Forbidden("Invalid Credentials" /* InvalidCredentials */);
        }
        data.modifiedBy = currentUser.id;
        return super.updateAll(data, where, options);
    }
    async updateById(id, data, options) {
        let currentUser = await this.getCurrentUser();
        currentUser = currentUser !== null && currentUser !== void 0 ? currentUser : options === null || options === void 0 ? void 0 : options.currentUser;
        if (!currentUser) {
            throw new rest_1.HttpErrors.Forbidden("Invalid Credentials" /* InvalidCredentials */);
        }
        data.modifiedBy = currentUser.id;
        return super.updateById(id, data, options);
    }
    async replaceById(id, data, options) {
        const currentUser = await this.getCurrentUser();
        if (!currentUser) {
            throw new rest_1.HttpErrors.Forbidden("Invalid Credentials" /* InvalidCredentials */);
        }
        data.modifiedBy = currentUser.id;
        return super.replaceById(id, data, options);
    }
    async deleteAllHard(where, options) {
        return super.deleteAll(where, options);
    }
    async deleteByIdHard(id, options) {
        return super.deleteById(id, options);
    }
    async deleteById(id, options) {
        // Do soft delete, no hard delete allowed
        return super.updateById(id, {
            deleted: true,
        }, options);
    }
    async deleteAll(where, options) {
        // Do soft delete, no hard delete allowed
        return super.updateAll({
            deleted: true,
        }, where, options);
    }
}
exports.DefaultTransactionalUserModifyRepository = DefaultTransactionalUserModifyRepository;
//# sourceMappingURL=default-transactional-user-modify-repository.base.js.map